##  Dashboard Versions
The contents of the onboarding dashboard vary depending on the version you're using.
### Dashboard Version 3
Dashboard version 3 includes content from dashboard version 2, with the following changes:
  * Links to learning resources were updated.
  * Some tasks were moved between milestones, and the task order was adjusted.
  * The TIME assessment metric was removed from the metrics list.


### Dashboard Version 2
The onboarding dashboard version 2 includes the following sections:
  * Onboarding Guide: This section provides an in-app guide that helps you navigate the onboarding process to SAP LeanIX Application Portfolio Management. To learn more, see [Onboarding Guide for SAP LeanIX Application Portfolio Management](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management?locale=en-US&state=PRODUCTION&version=CLOUD "The onboarding guide offers a streamlined onboarding process for SAP LeanIX Application Portfolio Management, providing step-by-step instructions, resources, and progress tracking.").
  * Best Practice Metrics: The onboarding best practice metrics help you focus on establishing data quality in your workspace right from the beginning of your SAP LeanIX journey. These metrics, aligned with the milestones outlined in the SAP LeanIX Academy courses, provide orientation on what good data looks like for each process step. For more information, see [Understanding Best Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
  * Support Channels: This section provides links to various enablement and support resources that you can use to find answers to your questions and maximize your experience.


### Dashboard Version 1
The onboarding dashboard version 1 includes the following sections:
  * Academy Courses APM Onboarding: This section provides links to the SAP LeanIX Academy courses relevant for enterprise architects.
  * Onboarding Best Practice Metrics Report: This report helps you focus on establishing data quality in your workspace right from the beginning of your SAP LeanIX journey. These metrics, aligned with the milestones outlined in the SAP LeanIX Academy courses, provide orientation on what good data looks like for each process step. For more information, see [Understanding Best Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
  * Further Resources: This section provides links to various enablement and support resources that you can use to find answers to your questions and maximize your experience.
